function res = isemptyobject(O)
% isemptyobject - checks whether an empty set contains any information at
%    all; consequently, the set is interpreted as the empty set 
%
% Syntax:
%    res = isemptyobject(O)
%
% Inputs:
%    O - emptySet object
%
% Outputs:
%    res - true/false
%
% Example: 
%    O = emptySet(2);
%    isemptyobject(O); % false
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Authors:       Mark Wetzlinger
% Written:       24-July-2023
% Last update:   ---
% Last revision: ---

% ------------------------------ BEGIN CODE -------------------------------

res = false;

% ------------------------------ END OF CODE ------------------------------
